@@ -58,8 +58,8 @@ class Checker(object):
         icondir = os.getenv("TASK_INDICATOR_ICONDIR")
         if icondir:
             self.indicator.set_icon_theme_path(icondir)
-            print("Appindicator theme path: %s, wanted: %s" % (self.indicator.get_icon_theme_path(), icondir))
-
+            print("Appindicator theme path: {0}, wanted: {1}".format(
+                self.indicator.get_icon_theme_path(), icondir))
 
         self.indicator.set_status(appindicator.STATUS_ACTIVE)
         self.indicator.set_attention_icon(self.icon_attn)
@@ -120,7 +120,8 @@ class Checker(object):
             if t["status"] == "pending"]
 
         for task in sorted(data, key=self.task_sort)[:10]:
-            item = gtk.CheckMenuItem(self.format_menu_label(task), use_underline=False)
+            item = gtk.CheckMenuItem(self.format_menu_label(task),
+                use_underline=False)
             if task.get("start"):
                 item.set_active(True)
             item.connect("activate", self.on_task_toggle)
@@ -140,7 +141,8 @@ class Checker(object):
 
     def format_menu_label(self, task):
         proj = task["project"].split(".")[-1]
-        title = u"%s:\t%s" % (proj, util.strip_description(task["description"]))
+        title = u"{0}:\t{1}".format(proj,
+            util.strip_description(task["description"]))
         return title
 
     def task_sort(self, task):
@@ -148,7 +150,7 @@ class Checker(object):
         is_pinned = "pin" in task.get("tags", [])
         is_running = "start" in task
         is_endless = "endless" in task.get("tags", [])
-        pri = {"H":3, "M": 2, "L": 1}.get(task.get("priority"), 0)
+        pri = {"H": 3, "M": 2, "L": 1}.get(task.get("priority"), 0)
         return (-is_running, -is_pinned, is_endless, -pri,
             -float(task.get("urgency", 0)))
 
@@ -200,7 +202,7 @@ class Checker(object):
                 elif k == "description":
                     command.append(v)
                 else:
-                    command.append("%s:%s" % (k, v))
+                    command.append("{0}:{1}".format(k, v))
             util.run_command(command)
 
         self.update_status()
@@ -246,7 +248,7 @@ class Checker(object):
             self.indicator.set_status(appindicator.STATUS_ATTENTION)
             self.stop_item.show()
 
-            msg = "%u/%s" % (len(tasks),
+            msg = "{0}/{1}".format(len(tasks),
                 self.format_duration(self.get_duration()))
 
             self.indicator.set_label(msg)
