@@ -31,7 +31,8 @@ class Dialog(gtk.Window):
 
         self.query_ctl = gtk.Entry()
         self.query_ctl.connect("changed", self._on_query_changed)
-        self.vbox.pack_start(self.query_ctl, expand=False, fill=True, padding=4)
+        self.vbox.pack_start(self.query_ctl, expand=False,
+            fill=True, padding=4)
 
         self.model = model = gtk.ListStore(str, str, str, str, str, str)
         self.model_filter = model_filter = model.filter_new()
@@ -88,7 +89,6 @@ class Dialog(gtk.Window):
         self.connect("key-press-event", self._on_keypress)
 
     def filter_tasks(self, model, iter):
-        # print("filter_tasks %s %s" % (model, iter), file=sys.stderr)
         if self.query is None:
             return True
 
@@ -171,4 +171,5 @@ class Dialog(gtk.Window):
             self.hide()
 
     def on_activate_task(self, uuid):
-        print("Activate task %s" % uuid, file=sys.stderr)
+        print("Activate task {0}".format(uuid),
+            file=sys.stderr)
